@@ -1,4 +1,5 @@
 from functools import wraps
+import warnings
 from types import FunctionType
 from typing import Callable
 
@@ -30,7 +31,9 @@ __all__ = [
     "isnan",
     "Device",
     "device",
-    "move_to_active_device",
+    "on_device",
+    "set_global_device",
+    "to_active_device",
     "zeros",
     "ones",
     "zero",
@@ -63,10 +66,15 @@ __all__ = [
     "maximum",
     "leaky_relu",
     "min",
+    "argmin",
     "max",
+    "argmax",
     "sum",
+    "nansum",
     "mean",
+    "nanmean",
     "std",
+    "nanstd",
     "logsumexp",
     "all",
     "any",
@@ -74,11 +82,13 @@ __all__ = [
     "le",
     "gt",
     "ge",
-    "cond",
     "bvn_cdf",
+    "cond",
+    "where",
     "scan",
     "sort",
     "argsort",
+    "quantile",
     "to_numpy",
 ]
 
@@ -205,7 +215,7 @@ class Device:
         # Set active name.
         Device.active_name = self.name
 
-        # Active the TF device manager, if it is available.
+        # Activate the TF device manager, if it is available.
         if Device._tf_manager:
             self._active_tf_manager = Device._tf_manager(self.name)
             self._active_tf_manager.__enter__()
@@ -224,26 +234,57 @@ class Device:
 @dispatch
 @abstract()
 def device(a: Numeric):
-    """Get the device on which a tensor lives or change the active device.
+    """Get the device on which a tensor lives.
 
     Args:
-        a (tensor or str): Tensor to get device of or name of device to change the
-            active device to.
+        a (tensor): Tensor to get device of.
 
     Returns:
-        str or `None`: Device of `a` if a tensor was given. Otherwise, there is no
-            return value.
+        str: Device of `a`.
     """
 
 
 @dispatch
-def device(name: str):
-    return Device(name)
+def device(device: str):  # pragma: no cover
+    warnings.warn(
+        "The use of `device` to change the active device is deprecated. Please use "
+        "`on_device` instead.",
+        category=DeprecationWarning,
+    )
+    return on_device(device)
 
 
 @dispatch
-@abstract(promote=None)
-def move_to_active_device(a: Numeric):  # pragma: no cover
+def on_device(device):
+    """Create a context to change the active device.
+
+    Args:
+        a (device): New active device.
+
+    Returns:
+        :class:`.Device`: Context to change the active device.
+    """
+    return on_device(str(device))
+
+
+@dispatch
+def on_device(device: str):
+    return Device(device)
+
+
+@dispatch
+def set_global_device(device):
+    """Change the active device globally.
+
+    Args:
+        a (device): New active device.
+    """
+    on_device(device).__enter__()
+
+
+@dispatch
+@abstract()
+def to_active_device(a: Numeric):  # pragma: no cover
     """Move a tensor to the active device.
 
     Args:
@@ -255,7 +296,12 @@ def move_to_active_device(a: Numeric):  # pragma: no cover
 
 
 @dispatch
-@abstract(promote=None)
+def to_active_device(a: Number):
+    return a
+
+
+@dispatch
+@abstract()
 def zeros(dtype: DType, *shape: Int):  # pragma: no cover
     """Create a tensor of zeros.
 
@@ -282,7 +328,7 @@ def zeros(ref: Numeric):
 
 
 @dispatch
-@abstract(promote=None)
+@abstract()
 def ones(dtype: DType, *shape: Int):  # pragma: no cover
     """Create a tensor of ones.
 
@@ -370,7 +416,7 @@ def eye(dtype: DType, *shape: Int):  # pragma: no cover
 
 
 @dispatch
-@abstract(promote=None)
+@abstract()
 def _eye2(dtype: DType, *shape: Int):  # pragma: no cover
     pass
 
@@ -396,7 +442,7 @@ def eye(ref: Numeric):
 
 
 @dispatch
-@abstract(promote=None)
+@abstract()
 def linspace(dtype: DType, a, b, num: Int):
     """Create a vector of `c` numbers ranging from `a` to `c`, distributed
     linearly.
@@ -418,7 +464,7 @@ def linspace(a, b, num: Int):
 
 
 @dispatch
-@abstract(promote=None)
+@abstract()
 def range(dtype: DType, start, stop, step):
     """Create a vector of numbers ranging from `start` to `stop` with step
     size `step`.
@@ -460,7 +506,7 @@ def range(stop):
 
 
 @dispatch
-@abstract(promote=None)
+@abstract()
 def cast(dtype: Numeric, a: DType):  # pragma: no cover
     """Cast an object to another data type.
 
@@ -793,12 +839,14 @@ def leaky_relu(a, alpha):  # pragma: no cover
 
 @dispatch
 @abstract()
-def min(a: Numeric, axis=None):  # pragma: no cover
+def min(a: Numeric, axis=None, squeeze=True):  # pragma: no cover
     """Take the minimum of a tensor, possibly along an axis.
 
     Args:
         a (tensor): Tensor.
         axis (int, optional): Optional axis.
+        squeeze (bool, optional): Squeeze the dimension after the reduction. Defaults
+            to `True`.
 
     Returns:
         tensor: Reduced tensor.
@@ -807,12 +855,29 @@ def min(a: Numeric, axis=None):  # pragma: no cover
 
 @dispatch
 @abstract()
-def max(a: Numeric, axis=None):  # pragma: no cover
+def argmin(a: Numeric, axis=None):  # pragma: no cover
+    """Take the indices corresponding to the minimum of a tensor, possibly along an
+    axis.
+
+    Args:
+        a (tensor): Tensor.
+        axis (int, optional): Optional axis.
+
+    Returns:
+        tensor: Indices.
+    """
+
+
+@dispatch
+@abstract()
+def max(a: Numeric, axis=None, squeeze=True):  # pragma: no cover
     """Take the maximum of a tensor, possibly along an axis.
 
     Args:
         a (tensor): Tensor.
         axis (int, optional): Optional axis.
+        squeeze (bool, optional): Squeeze the dimension after the reduction. Defaults
+            to `True`.
 
     Returns:
         tensor: Reduced tensor.
@@ -821,40 +886,78 @@ def max(a: Numeric, axis=None):  # pragma: no cover
 
 @dispatch
 @abstract()
-def sum(a: Numeric, axis=None):  # pragma: no cover
+def argmax(a: Numeric, axis=None):  # pragma: no cover
+    """Take the indices corresponding to the maximum of a tensor, possibly along an
+    axis.
+
+    Args:
+        a (tensor): Tensor.
+        axis (int, optional): Optional axis.
+
+    Returns:
+        tensor: Indices.
+    """
+
+
+@dispatch
+@abstract()
+def sum(a: Numeric, axis=None, squeeze=True):  # pragma: no cover
     """Sum a tensor, possibly along an axis.
 
     Args:
         a (tensor): Tensor.
         axis (int, optional): Optional axis.
+        squeeze (bool, optional): Squeeze the dimension after the reduction. Defaults
+            to `True`.
 
     Returns:
         tensor: Reduced tensor.
     """
 
 
+@dispatch
+def nansum(x, **kw_args):
+    """Like :func:`sum`, but ignores `NaN`s."""
+    available = ~B.isnan(x)
+    x = B.where(available, x, B.zero(x))
+    return B.sum(x, **kw_args)
+
+
 @dispatch
 @abstract()
-def mean(a: Numeric, axis=None):  # pragma: no cover
+def mean(a: Numeric, axis=None, squeeze=True):  # pragma: no cover
     """Take the mean of a tensor, possibly along an axis.
 
     Args:
         a (tensor): Tensor.
         axis (int, optional): Optional axis.
+        squeeze (bool, optional): Squeeze the dimension after the reduction. Defaults
+            to `True`.
 
     Returns:
         tensor: Reduced tensor.
     """
 
 
+@dispatch
+def nanmean(x, **kw_args):
+    """Like :func:`mean`, but ignores `NaN`s."""
+    available = ~B.isnan(x)
+    x = B.where(available, x, B.zero(x))
+    # Need to cast `available` away from booleans for `sum` to work reliably.
+    return B.sum(x, **kw_args) / B.sum(B.cast(B.dtype(x), available), **kw_args)
+
+
 @dispatch
 @abstract()
-def std(a: Numeric, axis=None):  # pragma: no cover
+def std(a: Numeric, axis=None, squeeze=True):  # pragma: no cover
     """Compute the standard deviation of a tensor, possibly along an axis.
 
     Args:
         a (tensor): Tensor.
         axis (int, optional): Optional axis.
+        squeeze (bool, optional): Squeeze the dimension after the reduction. Defaults
+            to `True`.
 
     Returns:
         tensor: Reduced tensor.
@@ -862,24 +965,40 @@ def std(a: Numeric, axis=None):  # pragma: no cover
 
 
 @dispatch
-def logsumexp(a, axis=None):  # pragma: no cover
+def nanstd(x, **kw_args):
+    """Like :func:`std`, but ignores `NaN`s."""
+    inner_kw_args = kw_args.copy()
+    inner_kw_args["squeeze"] = False
+    mu = B.nanmean(x, **inner_kw_args)
+    return B.sqrt(B.nanmean(B.power(x - mu, 2), **kw_args))
+
+
+@dispatch
+def logsumexp(a, axis=None, squeeze=True):  # pragma: no cover
     """Exponentiate a tensor, sum it, and then take the logarithm, possibly
     along an axis.
 
     Args:
         a (tensor): Tensor.
         axis (int, optional): Optional axis.
+        squeeze (bool, optional): Squeeze the dimension after the reduction. Defaults
+            to `True`.
 
     Returns:
         tensor: Reduced tensor.
     """
-    a_max = max(a, axis=axis)
-    # Put the axis back if one is specified.
-    if axis is None:
-        a_expanded = a_max
+    a_max = max(a, axis=axis, squeeze=True)
+    # Expand `a_max` if an axis is specified.
+    if axis is not None:
+        a_max_inner = B.expand_dims(a_max, axis=axis)
     else:
-        a_expanded = B.expand_dims(a_max, axis=axis)
-    return log(sum(exp(a - a_expanded), axis=axis)) + a_max
+        a_max_inner = a_max
+    # Handle `squeeze` correctly.
+    if axis is not None and not squeeze:
+        a_max_outer = B.expand_dims(a_max, axis=axis)
+    else:
+        a_max_outer = a_max
+    return log(sum(exp(a - a_max_inner), axis=axis, squeeze=squeeze)) + a_max_outer
 
 
 # Logical reductions:
@@ -887,12 +1006,14 @@ def logsumexp(a, axis=None):  # pragma: no cover
 
 @dispatch
 @abstract()
-def all(a: Numeric, axis=None):  # pragma: no cover
+def all(a: Numeric, axis=None, squeeze=True):  # pragma: no cover
     """Logical all of a tensor, possibly along an axis.
 
     Args:
         a (tensor): Tensor.
         axis (int, optional): Optional axis.
+        squeeze (bool, optional): Squeeze the dimension after the reduction. Defaults
+            to `True`.
 
     Returns:
         tensor: Reduced tensor.
@@ -901,12 +1022,14 @@ def all(a: Numeric, axis=None):  # pragma: no cover
 
 @dispatch
 @abstract()
-def any(a: Numeric, axis=None):  # pragma: no cover
+def any(a: Numeric, axis=None, squeeze=True):  # pragma: no cover
     """Logical any of a tensor, possibly along an axis.
 
     Args:
         a (tensor): Tensor.
         axis (int, optional): Optional axis.
+        squeeze (bool, optional): Squeeze the dimension after the reduction. Defaults
+            to `True`.
 
     Returns:
         tensor: Reduced tensor.
@@ -1017,6 +1140,22 @@ def _cond(condition: Numeric, f_true: FunctionType, f_false: FunctionType, *args
         return f_false(*args)
 
 
+@dispatch
+@abstract(promote=3)
+def where(condition, a, b):  # pragma: no cover
+    """In a broadcasting fashion, take from `x` if `condition` is true; otherwise,
+    take from `y`.
+
+    Args:
+        condition (tensor): Condition.
+        a (tensor): Tensor to take from if `condition` is true.
+        b (tensor): Tensor to take from if `condition` is false.
+
+    Returns:
+        tensor: Tensor where every element is either from `x` or from `y`.
+    """
+
+
 @dispatch
 def scan(f: Callable, xs, *init_state):
     """Perform a TensorFlow-style scanning operation.
@@ -1054,7 +1193,7 @@ def scan(f: Callable, xs, *init_state):
 
 
 @dispatch
-@abstract(promote=None)
+@abstract()
 def sort(a: Numeric, axis=-1, descending=False):
     """Sort a tensor along an axis in ascending order.
 
@@ -1070,7 +1209,7 @@ def sort(a: Numeric, axis=-1, descending=False):
 
 
 @dispatch
-@abstract(promote=None)
+@abstract()
 def argsort(a: Numeric, axis=-1, descending=False):
     """Get the indices that would a tensor along an axis in ascending order.
 
@@ -1085,6 +1224,21 @@ def argsort(a: Numeric, axis=-1, descending=False):
     """
 
 
+@dispatch
+@abstract(promote=2)
+def quantile(a, q, axis=None):
+    """Compute quantiles.
+
+    Args:
+        a (tensor): Tensor to compute quantiles of.
+        q (tensor): Quantiles to compute. Must be numbers in `[0, 1]`.
+        axis (int, optional): Axis to compute quantiles along. Defaults to `None`.
+
+    Returns:
+        tensor: Quantiles.
+    """
+
+
 NPOrNum = Union[NPNumeric, Number]  #: Type NumPy numeric or number.
 add_conversion_method(AGNumeric, NPOrNum, lambda x: x._value)
 add_conversion_method(TFNumeric, NPOrNum, lambda x: x.numpy())
