@@ -37,7 +37,7 @@ def device(a: NPNumeric):
 
 
 @dispatch
-def move_to_active_device(a: NPNumeric):
+def to_active_device(a: NPNumeric):
     return a
 
 
@@ -172,38 +172,48 @@ def maximum(a: Numeric, b: Numeric):
 
 
 @dispatch
-def min(a: Numeric, axis=None):
-    return np.min(a, axis=axis)
+def min(a: Numeric, axis=None, squeeze=True):
+    return np.min(a, axis=axis, keepdims=not squeeze)
 
 
 @dispatch
-def max(a: Numeric, axis=None):
-    return np.max(a, axis=axis)
+def argmin(a: Numeric, axis=None):
+    return np.argmin(a, axis=axis)
 
 
 @dispatch
-def sum(a: Numeric, axis=None):
-    return np.sum(a, axis=axis)
+def max(a: Numeric, axis=None, squeeze=True):
+    return np.max(a, axis=axis, keepdims=not squeeze)
 
 
 @dispatch
-def mean(a: Numeric, axis=None):
-    return np.mean(a, axis=axis)
+def argmax(a: Numeric, axis=None):
+    return np.argmax(a, axis=axis)
 
 
 @dispatch
-def std(a: Numeric, axis=None):
-    return np.std(a, axis=axis, ddof=0)
+def sum(a: Numeric, axis=None, squeeze=True):
+    return np.sum(a, axis=axis, keepdims=not squeeze)
 
 
 @dispatch
-def all(a: Numeric, axis=None):
-    return np.all(a, axis=axis)
+def mean(a: Numeric, axis=None, squeeze=True):
+    return np.mean(a, axis=axis, keepdims=not squeeze)
 
 
 @dispatch
-def any(a: Numeric, axis=None):
-    return np.any(a, axis=axis)
+def std(a: Numeric, axis=None, squeeze=True):
+    return np.std(a, axis=axis, ddof=0, keepdims=not squeeze)
+
+
+@dispatch
+def all(a: Numeric, axis=None, squeeze=True):
+    return np.all(a, axis=axis, keepdims=not squeeze)
+
+
+@dispatch
+def any(a: Numeric, axis=None, squeeze=True):
+    return np.any(a, axis=axis, keepdims=not squeeze)
 
 
 @dispatch
@@ -231,6 +241,11 @@ def bvn_cdf(a: Numeric, b: Numeric, c: Numeric):
     return _bvn_cdf(a, b, c)
 
 
+@dispatch
+def where(condition: Numeric, a: Numeric, b: Numeric):
+    return np.where(condition, a, b)
+
+
 @dispatch
 def sort(a: Numeric, axis=-1, descending=False):
     if descending:
@@ -245,3 +260,8 @@ def argsort(a: Numeric, axis=-1, descending=False):
         return np.argsort(-a, axis=axis)
     else:
         return np.argsort(a, axis=axis)
+
+
+@dispatch
+def quantile(a: Numeric, q: Numeric, axis=None):
+    return np.quantile(a, q, axis=axis, interpolation="linear")
