@@ -1,5 +1,6 @@
 import math
 
+import warnings
 import numpy as np
 from plum import Union
 
@@ -14,10 +15,12 @@ __all__ = [
     "rank",
     "length",
     "size",
-    "isscalar",
+    "is_scalar",
+    "isscalar",  # Deprecated
     "expand_dims",
     "squeeze",
     "uprank",
+    "broadcast_to",
     "diag",
     "diag_extract",
     "diag_construct",
@@ -129,7 +132,7 @@ size = length  #: Alias for `length`.
 
 
 @dispatch
-def isscalar(a: Numeric):
+def is_scalar(a: Numeric):
     """Check whether a tensor is a scalar.
 
     Args:
@@ -141,6 +144,14 @@ def isscalar(a: Numeric):
     return rank(a) == 0
 
 
+def isscalar(a):
+    warnings.warn(
+        "The use of `isscalar` is deprecated. Please use `is_scalar` instead.",
+        category=DeprecationWarning,
+    )
+    return is_scalar(a)
+
+
 @dispatch
 @abstract()
 def expand_dims(a: Numeric, axis=0):  # pragma: no cover
@@ -194,6 +205,20 @@ def uprank(a: Numeric, rank=2):
     return a
 
 
+@dispatch
+@abstract()
+def broadcast_to(a: Numeric, *shape: Int):
+    """Broadcast a tensor to a certain shape.
+
+    Args:
+        a (tensor): Tensor to broadcast.
+        *shape (shape): New shape.
+
+    Returns:
+        tensor: Broadcasted tensor.
+    """
+
+
 @dispatch
 @abstract()
 def diag(a: Numeric):
