@@ -22,6 +22,11 @@ def squeeze(a: Numeric):
     return tf.squeeze(a)
 
 
+@dispatch
+def broadcast_to(a: Numeric, *shape: Int):
+    return tf.broadcast_to(a, shape)
+
+
 @dispatch
 def diag(a: Numeric):
     if B.rank(a) == 1:
