@@ -42,7 +42,7 @@ def device(a: TorchNumeric):
 
 
 @dispatch
-def move_to_active_device(a: TorchNumeric):
+def to_active_device(a: TorchNumeric):
     return a.to(B.Device.active_name)
 
 
@@ -183,59 +183,69 @@ def maximum(a: Numeric, b: Numeric):
 
 
 @dispatch
-def min(a: Numeric, axis=None):
+def min(a: Numeric, axis=None, squeeze=True):
     if axis is None:
         return torch.min(a)
     else:
-        return torch.min(a, dim=axis)[0]
+        return torch.min(a, dim=axis, keepdim=not squeeze)[0]
 
 
 @dispatch
-def max(a: Numeric, axis=None):
+def argmin(a: Numeric, axis=None):
+    return torch.argmin(a, dim=axis)
+
+
+@dispatch
+def max(a: Numeric, axis=None, squeeze=True):
     if axis is None:
         return torch.max(a)
     else:
-        return torch.max(a, dim=axis)[0]
+        return torch.max(a, dim=axis, keepdim=not squeeze)[0]
 
 
 @dispatch
-def sum(a: Numeric, axis=None):
+def argmax(a: Numeric, axis=None):
+    return torch.argmax(a, dim=axis)
+
+
+@dispatch
+def sum(a: Numeric, axis=None, squeeze=True):
     if axis is None:
         return torch.sum(a)
     else:
-        return torch.sum(a, dim=axis)
+        return torch.sum(a, dim=axis, keepdim=not squeeze)
 
 
 @dispatch
-def mean(a: Numeric, axis=None):
+def mean(a: Numeric, axis=None, squeeze=True):
     if axis is None:
         return torch.mean(a)
     else:
-        return torch.mean(a, dim=axis)
+        return torch.mean(a, dim=axis, keepdim=not squeeze)
 
 
 @dispatch
-def std(a: Numeric, axis=None):
+def std(a: Numeric, axis=None, squeeze=True):
     if axis is None:
         return torch.std(a, unbiased=False)
     else:
-        return torch.std(a, dim=axis, unbiased=False)
+        return torch.std(a, dim=axis, unbiased=False, keepdim=not squeeze)
 
 
 @dispatch
-def all(a: Numeric, axis=None):
+def all(a: Numeric, axis=None, squeeze=True):
     if axis is None:
-        return a.all()
+        return torch.all(a)
     else:
-        return a.all(dim=axis)
+        return torch.all(a, dim=axis, keepdim=not squeeze)
 
 
 @dispatch
-def any(a: Numeric, axis=None):
+def any(a: Numeric, axis=None, squeeze=True):
     if axis is None:
-        return a.any()
+        return torch.any(a)
     else:
-        return a.any(dim=axis)
+        return torch.any(a, dim=axis, keepdim=not squeeze)
 
 
 @dispatch
@@ -266,6 +276,11 @@ def bvn_cdf(a: Numeric, b: Numeric, c: Numeric):
     return _bvn_cdf(a, b, c)
 
 
+@dispatch
+def where(condition: Numeric, a: Numeric, b: Numeric):
+    return torch.where(condition, a, b)
+
+
 @dispatch
 def sort(a: Numeric, axis=-1, descending=False):
     return torch.sort(a, dim=axis, descending=descending)[0]
@@ -274,3 +289,8 @@ def sort(a: Numeric, axis=-1, descending=False):
 @dispatch
 def argsort(a: Numeric, axis=-1, descending=False):
     return torch.argsort(a, dim=axis, descending=descending)
+
+
+@dispatch
+def quantile(a: Numeric, q: Numeric, axis=None):
+    return torch.quantile(a, q, dim=axis)
